module Decoder(CLK, RESET, Q, SEG, DIGIT);

	input CLK, RESET;
	input [15:0] Q;
	output [3:0] SEG, DIGIT;

	reg [3:0] SEG, DIGIT, count;
	reg [14:0] temp_count = 0;

	always @(posedge CLK or negedge RESET)
	begin
		if (!RESET) temp_count <= 0;
		else temp_count <= temp_count + 1;
	end
	
	assign enable = (temp_count == 0) ? 1 : 0;
	
	always @(posedge CLK or negedge RESET)
	begin
		if (!RESET) count <= 0;
		else if (enable == 1) count <= count + 1;
	end
	
	always @(posedge CLK)
	begin
		if (!RESET)
		begin
			SEG <= 0;
			DIGIT <= 0;
		end
		else if(enable == 1)
			case (count)
				0:
				begin
					SEG <= (Q % 10000) / 1000;
					DIGIT <= 4'b0001;
				end
				2:
				begin
					SEG <= (Q % 1000) / 100;
					DIGIT <= 4'b0010;
				end
				4:
				begin
					SEG <= (Q % 100) / 10;
					DIGIT <= 4'b0100;
				end
				6:
				begin
					SEG <= Q % 10;
					DIGIT <= 4'b1000;
				end
				default:
				begin
					SEG <= 0;
					DIGIT <= 0;
				end
			endcase
	end
	
endmodule
